@@ -214,16 +214,13 @@ class TomorrowioV4:
 
         if resp.status == HTTPStatus.OK:
             self._num_api_requests += 1
-            # ignore "range for timestep not valid warning"
             for warning in set(
-                warning["message"]
-                for warning in resp_json.get("warnings", [])
-                if warning["code"] != 246009
+                warning["message"] for warning in resp_json.get("warnings", [])
             ):
-                _LOGGER.warning(
+                _LOGGER.info(
                     (
-                        "While calling the API for the following timesteps: [%s], the "
-                        "following warning was returned: %s"
+                        "While calling the API for the timesteps [%s], the following "
+                        "warning was returned: %s"
                     ),
                     ", ".join(params["timesteps"]),
                     warning,
